@@ -17,6 +17,10 @@ def convert_enum_type(param_name: str, enum_class: Type[Enum]) -> Callable:
 
     def convert_enum_type_wrapper(request: Request) -> EnumType:
         enum_type_str = request.query_params.get(param_name)
+        if not enum_type_str:
+            enum_type_str = request.path_params.get(param_name)
+            if not enum_type_str:
+                enum_type_str = request.form().get(param_name)
         type_enum_list = [tmp for tmp in enum_class if tmp.name == enum_type_str or tmp.value == enum_type_str]
         if type_enum_list:
             return type_enum_list[0]
