@@ -4,11 +4,13 @@ from pydantic import BaseModel
 from starlette.datastructures import FormData
 from starlette.requests import Request
 
+from afeng_tools.application_tool.application_models import AppInfo
 from afeng_tools.convert_tool.type_convert_tools import convert_value_to_type
 
 
 def form_params_convert_to_model(form_model_class: Type[BaseModel]):
     """将表单参数转换为pydantic的Model对象"""
+
     async def func_wrap(request: Request):
         body = await request.form()
         if body:
@@ -18,6 +20,7 @@ def form_params_convert_to_model(form_model_class: Type[BaseModel]):
                 if tmp_key in field_dict:
                     model_value_dict[tmp_key] = convert_value_to_type(tmp_value, field_dict.get(tmp_key).annotation)
             return form_model_class(**model_value_dict)
+
     return func_wrap
 
 
@@ -30,3 +33,11 @@ async def do_handle_form_array_item(form_data: FormData) -> FormData:
         else:
             new_form_data_list.append((tmp_key, form_data.get(tmp_key)))
     return FormData(new_form_data_list)
+
+
+def get_request_app_info(request: Request, app_dict: dict[str, AppInfo]):
+    request_path = request.url.path
+    for app_info in app_dict.values():
+        if request_path.startswith(app_info.prefix + '/'):
+            request.scope['app_info'] = app_info
+            return app_info
