@@ -9,7 +9,11 @@ def run(cmd, is_print: bool = True) -> list[str]:
     :return: 命令输出信息
     """
     output = os.popen(cmd)
-    line_list = output.buffer.read().decode('utf-8').split('\n')
+    output_byte = output.buffer.read()
+    try:
+        line_list = output_byte.decode('utf-8').split('\n')
+    except Exception as ex:
+        line_list = output_byte.decode('gbk').split('\n')
     if is_print:
         for tmp_line in line_list:
             print(tmp_line)
